@@ -11,10 +11,12 @@ from onnx2tf.utils.common_functions import (
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
+    pre_explicit_broadcast,
     explicit_broadcast,
     pre_process_transpose,
     post_process_transpose,
     disable_unnecessary_transpose,
+    shape_unmatched_special_avoidance_workaround,
 )
 
 
@@ -82,6 +84,30 @@ def make_node(
             input_tensor_2=input_tensor_2,
         )
 
+    input_tensor_1, input_tensor_2 = pre_explicit_broadcast(
+        input_tensor_1=input_tensor_1,
+        input_tensor_2=input_tensor_2,
+    )
+
+    input_tensor_1, input_tensor_2 = explicit_broadcast(
+        const_or_var_1=input_tensor_1,
+        const_or_var_2=input_tensor_2,
+        graph_node=graph_node,
+        tf_layers_dict= tf_layers_dict,
+    )
+
+    # Shape Unmatched Special Avoidance Workaround
+    # At least one True value for same_input_shape_as_onnx
+    # At least one True value in nhwc_flags
+    # same_input_shape_as_onnx == True and nhwc_flags == False and 3D or 4D or 5D tensor is NHWC transposed
+    input_tensor_1, input_tensor_2 = shape_unmatched_special_avoidance_workaround(
+        graph_node_input_1=graph_node_input_1,
+        graph_node_input_2=graph_node_input_2,
+        input_tensor_1=input_tensor_1,
+        input_tensor_2=input_tensor_2,
+        tf_layers_dict=tf_layers_dict,
+    )
+
     # Param replacement
     input_tensor_1 = replace_parameter(
         value_before_replacement=input_tensor_1,
@@ -96,13 +122,6 @@ def make_node(
         **kwargs,
     )
 
-    input_tensor_1, input_tensor_2 = explicit_broadcast(
-        const_or_var_1=input_tensor_1,
-        const_or_var_2=input_tensor_2,
-        graph_node=graph_node,
-        tf_layers_dict= tf_layers_dict,
-    )
-
     # Pre-process transpose
     input_tensor_1 = pre_process_transpose(
         value_before_transpose=input_tensor_1,
