@@ -9,13 +9,18 @@ from onnx2tf.utils.common_functions import (
     get_constant_or_variable,
     print_node_info,
     inverted_operation_enable_disable,
+    pre_explicit_broadcast,
     explicit_broadcast,
     make_tf_node_info,
+    get_replacement_parameter,
+    pre_process_transpose,
+    post_process_transpose,
 )
 
 
 @print_node_info
 @inverted_operation_enable_disable
+@get_replacement_parameter
 def make_node(
     *,
     graph_node: gs.Node,
@@ -55,13 +60,17 @@ def make_node(
 
     replace_prelu_to_pseudo_prelu = kwargs['replace_prelu_to_pseudo_prelu']
 
+    _, slope = pre_explicit_broadcast(
+        input_tensor_1=input_tensor,
+        input_tensor_2=slope,
+    )
+
     _, slope = explicit_broadcast(
         const_or_var_1=input_tensor,
         const_or_var_2=slope,
         graph_node=graph_node,
         tf_layers_dict= tf_layers_dict
     )
-    slope_rank = len(slope.shape)
 
     graph_node_output: gs.Variable = graph_node.outputs[0]
     shape = graph_node_output.shape
@@ -72,8 +81,19 @@ def make_node(
         'optype': graph_node.op,
         'shape': shape,
         'dtype': dtype,
+        'nhwc': tf_layers_dict[graph_node_input_1.name]['nhwc'] \
+            if isinstance(graph_node_input_1, gs.Variable) \
+                and 'nhwc' in tf_layers_dict[graph_node_input_1.name].keys() else False
     }
 
+    # Pre-process transpose
+    input_tensor = pre_process_transpose(
+        value_before_transpose=input_tensor,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+
     # Generation of TF OP
     if replace_prelu_to_pseudo_prelu:
         pos = tf.nn.relu(input_tensor)
@@ -86,6 +106,14 @@ def make_node(
             shared_axes=shared_axes,
         )(input_tensor)
 
+    # Post-process transpose
+    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
         make_tf_node_info(
