@@ -19,9 +19,13 @@ from onnx2tf.utils.common_functions import (
     upsampling3d_bilinear,
     upsampling3d_bicubic,
     upsampling3d_nearest,
+    pre_process_transpose,
+    post_process_transpose,
 )
 from onnx2tf.utils.colors import Color
 
+INF_INDEX_VALUE: int = 4294967296
+
 
 @print_node_info
 @inverted_operation_enable_disable
@@ -53,6 +57,44 @@ def make_node(
         graph_node.inputs[0],
         before_op_output_shape_trans,
     )
+    input_tensor = tf_layers_dict[input_tensor.name]['tf_node'] \
+        if isinstance(input_tensor, gs.Variable) else input_tensor
+    input_tensor_shape = input_tensor.shape
+    input_tensor_rank = len(input_tensor_shape)
+    # Workaround to avoid as many Resize failures as possible
+    # for models with useless Transpose immediately before them.
+    # If the input geometry of the ONNX and the input geometry of the TF model match,
+    # the input geometry on the TF model side is forcibly transposed to the NWC or NHWC or NDHWC format.
+    # However, if all dimensions of CW or CHW or CDHW have the same value,
+    # the forced transposition process is skipped because it may destroy the structure of the model.
+    onnx_input_shape = [
+        dim if isinstance(dim, int) else None for dim in graph_node.inputs[0].shape
+    ]
+    tf_input_shape = [
+        dim if isinstance(dim, int) else None for dim in input_tensor_shape
+    ]
+    if len(onnx_input_shape) > 1 and len(tf_input_shape) > 1 \
+        and onnx_input_shape == tf_input_shape:
+
+        shape_for_judging_skip = [
+            dim if dim is not None else INF_INDEX_VALUE for dim in onnx_input_shape[1:]
+        ]
+        if shape_for_judging_skip.count(shape_for_judging_skip[0]) != len(shape_for_judging_skip):
+            if len(onnx_input_shape) == 4:
+                # 2D
+                input_tensor = tf.transpose(
+                    a=input_tensor,
+                    perm=[0,2,3,1],
+                )
+                before_op_output_shape_trans = True
+            elif len(onnx_input_shape) == 5:
+                # 3D
+                input_tensor = tf.transpose(
+                    a=input_tensor,
+                    perm=[0,2,3,4,1],
+                )
+                before_op_output_shape_trans = True
+
     roi = None
     scales = None
     if len(graph_node.inputs) >= 2:
@@ -81,10 +123,6 @@ def make_node(
     shape = graph_node_output.shape
     dtype = graph_node_output.dtype
 
-    input_tensor = tf_layers_dict[input_tensor.name]['tf_node'] \
-        if isinstance(input_tensor, gs.Variable) else input_tensor
-    input_tensor_shape = input_tensor.shape
-    input_tensor_rank = len(input_tensor_shape)
     roi = tf_layers_dict[roi.name]['tf_node'] \
         if (isinstance(roi, gs.Variable) and roi.name != '') else roi
     scales = tf_layers_dict[scales.name]['tf_node'] \
@@ -162,40 +200,37 @@ def make_node(
         # The number of elements of 'sizes' should be the same as the rank of input 'X'
         if isinstance(sizes, gs.Variable):
             sizes = sizes.set_shape(input_tensor_shape.shape)
-            new_size = tf.cast(sizes[1:3], tf.int32)
+            new_size = tf.cast(sizes[1:input_tensor_rank-1], tf.int32)
         elif isinstance(sizes, np.ndarray):
-            new_size = tf.cast(sizes[1:3], tf.int32)
+            new_size = tf.cast(sizes[1:input_tensor_rank-1], tf.int32)
         elif tf.keras.backend.is_keras_tensor(sizes):
-            new_size = tf.cast(tf.slice(sizes, [1], [2]), tf.int32)
+            new_size = tf.cast(tf.slice(sizes, [1], [input_tensor_rank-2]), tf.int32)
     elif scales is not None:
         # only scales is defined
         if hasattr(graph_node_output, 'shape') \
-            and graph_node_output.shape is not None \
-            and isinstance(graph_node_output.shape[-2], int) \
-            and isinstance(graph_node_output.shape[-1], int):
-            new_size = graph_node_output.shape[-2:len(graph_node_output.shape)] # Estimated from ONNX output shape
+            and graph_node_output.shape is not None:
+            numeric_bools = np.asarray([isinstance(graph_node_output.shape[-(idx+1)], int) for idx in range(input_tensor_rank-2)])
+            if numeric_bools.all():
+                new_size = graph_node_output.shape[-2:len(graph_node_output.shape)] # Estimated from ONNX output shape
+            else:
+                h_w_scale = scales[1:input_tensor_rank-1]
+                h_w_shape = input_tensor_shape[1:input_tensor_rank-1]
+                new_size = tf.cast(h_w_scale * tf.cast(h_w_shape, scales.dtype), tf.int32)
         else:
-            h_w_scale = scales[1:3]
-            h_w_shape = input_tensor_shape[1:3]
+            h_w_scale = scales[1:input_tensor_rank-1]
+            h_w_shape = input_tensor_shape[1:input_tensor_rank-1]
             new_size = tf.cast(h_w_scale * tf.cast(h_w_shape, scales.dtype), tf.int32)
 
-    # Tensorflow require the shape of "size" in the "tf.image.resize" must be known at
-    # graph creation time. However in the dynamic shape situation, the shape of "new_size"
-    # will be "None", the actual shape can only be determine at runtime. But we know
-    # "new_size" should always contain [h, w], therefore the shape must be 2.
-    if hasattr(new_size, 'set_shape'):
-        new_size.set_shape([2])
-
     if hasattr(new_size, '_inferred_value'):
         new_size_values = new_size._inferred_value
         if (new_size_values is None or new_size_values.count(None) == len(new_size_values)) \
-            and sum([1 if isinstance(s, str) else 0 for s in graph_node_output.shape[1:3]]) == 0:
+            and sum([1 if isinstance(s, str) else 0 for s in graph_node_output.shape[1:input_tensor_rank-1]]) == 0:
             tensor_rank = len(graph_node_output.shape)
             convertion_table = [0] + [i for i in range(2, tensor_rank)] + [1]
             new_values = [0] * tensor_rank
             for new_idx, idx in enumerate(convertion_table):
                 new_values[new_idx] = graph_node_output.shape[idx]
-            new_size = new_values[-3:-1]
+            new_size = new_values[-(input_tensor_rank-1):-1]
 
     if (replace_argmax_to_fused_argmax_and_indicies_is_int64 \
         or replace_argmax_to_fused_argmax_and_indicies_is_float32) \
@@ -254,6 +289,14 @@ def make_node(
         **kwargs,
     )
 
+    # Pre-process transpose
+    input_tensor = pre_process_transpose(
+        value_before_transpose=input_tensor,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+
     resized_tensor = None
     boxes = None
     box_indices = None
@@ -303,6 +346,19 @@ def make_node(
             }
         )(input_tensor)
         tf_op_type = tf_resize
+    elif coordinate_transformation_mode == "half_pixel":
+        align_corners = False
+        half_pixel_centers = True
+        resized_tensor = Lambda(
+            tf_resize,
+            arguments={
+                'new_size': new_size,
+                'align_corners': align_corners,
+                'half_pixel_centers': half_pixel_centers,
+                'name': graph_node.name,
+            }
+        )(input_tensor)
+        tf_op_type = tf_resize
     else:
         resized_tensor = tf.image.resize(
             images=input_tensor,
@@ -314,6 +370,14 @@ def make_node(
 
     tf_layers_dict[graph_node_output.name]['tf_node'] = resized_tensor
 
+    # Post-process transpose
+    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
         make_tf_node_info(
