@@ -6,13 +6,15 @@ import tensorflow as tf
 import onnx_graphsurgeon as gs
 from typing import List
 from onnx2tf.utils.common_functions import (
-    get_replacement_parameter,
     replace_parameter,
     get_constant_or_variable,
     print_node_info,
     inverted_operation_enable_disable,
     convert_axis,
     make_tf_node_info,
+    get_replacement_parameter,
+    pre_process_transpose,
+    post_process_transpose,
 )
 
 
@@ -110,6 +112,14 @@ def make_node(
         **kwargs,
     )
 
+    # Pre-process transpose
+    input_tensor = pre_process_transpose(
+        value_before_transpose=input_tensor,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+
     # Generation of TF OP
     splited_tensors = \
         tf.split(
@@ -121,6 +131,13 @@ def make_node(
         )
     for splited_tensor, graph_node_output in zip(splited_tensors, graph_node_outputs):
         tf_layers_dict[graph_node_output.name]['tf_node'] = splited_tensor
+        # Post-process transpose
+        tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+            value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
+            param_target='outputs',
+            param_name=graph_node_output.name,
+            **kwargs,
+        )
 
     # Generation of Debug Info
     tf_outputs = {f"output{idx}": value for idx, value in enumerate(splited_tensors)}
