@@ -19,6 +19,8 @@ from onnx2tf.utils.enums import (
 )
 
 INF_INDEX_VALUE: int = 4294967296
+ONNX_INF_INDEX_VALUE = sys.maxsize # 9223372036854775807
+
 
 def get_replacement_parameter(func):
     @wraps(func)
@@ -2197,17 +2199,89 @@ def shape_unmatched_special_avoidance_workaround(
 
     return input_tensor_1, input_tensor_2
 
+
 def calc_output_shape_conv_transpose(input_shape, kernel, pad_mode, output_padding, stride, dilation):
-    out_height = conv_utils.deconv_output_length(input_shape[0],
-                                                 kernel[0],
-                                                 padding=pad_mode.lower(),
-                                                 output_padding=output_padding[0],
-                                                 stride=stride[0],
-                                                 dilation=dilation[0])
-    out_width = conv_utils.deconv_output_length(input_shape[1],
-                                                kernel[1],
-                                                padding=pad_mode.lower(),
-                                                output_padding=output_padding[1],
-                                                stride=stride[1],
-                                                dilation=dilation[1])
-    return [out_height, out_width]
+
+    assert len(input_shape) == len(kernel) == len(output_padding) == len(stride) == len(dilation),\
+        "All parameters should have same length"
+
+    output_shape = []
+
+    for i, k, p, s, d in zip(input_shape, kernel, output_padding, stride, dilation):
+        output_shape.append(conv_utils.deconv_output_length(input_length=i,
+                                                            filter_size=k,
+                                                            padding=pad_mode.lower(),
+                                                            output_padding=p,
+                                                            stride=s,
+                                                            dilation=d))
+
+    return output_shape
+
+
+def replace_max_values_negative_values(
+    *,
+    input_tensor_shape: np.asarray,
+    index_list: np.asarray,
+    axes: np.asarray,
+) -> List[int]:
+    if axes is None:
+        return index_list
+
+    for axis in axes:
+        data_shape_length = input_tensor_shape[axis]
+        if data_shape_length is None:
+            continue
+
+        # Max Value
+        """
+        9223372036854775807 = -1
+        9223372036854775806 = -2
+        9223372036854775805 = -3
+        9223372036854775804 = -4
+        9223372036854775803 = -5
+        """
+        maxvalue_index_list = [
+            ONNX_INF_INDEX_VALUE - i \
+                for i in range(data_shape_length)
+        ]
+        maxvalue_substitution_index_list = [
+            i - ONNX_INF_INDEX_VALUE + data_shape_length \
+                for i in maxvalue_index_list
+        ]
+        """
+        maxvalue_index_dict
+            9223372036854775807: 4
+            9223372036854775806: 3
+            9223372036854775805: 2
+            9223372036854775804: 1
+            9223372036854775803: 0
+        """
+        maxvalue_index_dict = {
+            i: j for i,j in zip(maxvalue_index_list, maxvalue_substitution_index_list)
+        }
+        # Negative Value
+        negativevalue_substitution_index_list = [
+            -i - 1 for i in range(data_shape_length)
+        ]
+        """
+        negativevalue_index_dict
+            -1: 4
+            -2: 3
+            -3: 2
+            -4: 1
+            -5: 0
+        """
+        negativevalue_index_dict = {
+            i: i+data_shape_length for i in negativevalue_substitution_index_list
+        }
+
+        # replace max values
+        index_list[axis] = index_list[axis] \
+            if index_list[axis] not in maxvalue_index_dict.keys() \
+                else maxvalue_index_dict[index_list[axis]]
+
+        # replace negative values
+        index_list[axis] = index_list[axis] \
+            if index_list[axis] not in negativevalue_index_dict.keys() \
+                else negativevalue_index_dict[index_list[axis]]
+    return index_list
