@@ -22,6 +22,8 @@ ONNX_DTYPES_TO_TF_DTYPES = {
 
     TensorProto.BOOL: tf.bool,
 
+    TensorProto.STRING: tf.string,
+
     # tf.qint8
     # tf.qint16
     # tf.qint32
@@ -48,4 +50,22 @@ NUMPY_DTYPES_TO_TF_DTYPES = {
     np.dtype('int64'): tf.int64,
 
     np.dtype('bool_'): tf.bool,
-}
\ No newline at end of file
+}
+
+TF_DTYPES_TO_NUMPY_DTYPES = {
+    tf.float16: np.dtype('int32'),
+    tf.float32: np.dtype('float32'),
+    tf.float64: np.dtype('float64'),
+
+    tf.uint8: np.dtype('uint8'),
+    tf.uint16: np.dtype('uint16'),
+    tf.uint32: np.dtype('uint32'),
+    tf.uint64: np.dtype('uint64'),
+
+    tf.int8: np.dtype('int8'),
+    tf.int16: np.dtype('int16'),
+    tf.int32: np.dtype('int32'),
+    tf.int64: np.dtype('int64'),
+
+    tf.bool: np.dtype('bool_'),
+}
